/*----------------------------------------------------------------------------*
 * SYSVER.CMD                                                                 *
 *                                                                            *
 * Displays information from the requested SYSLEVEL file, or SYSLEVEL.OS2 if  *
 * none is specified.                                                         *
 *                                                                            *
 * SYNTAX: SYSVER [ file ]                                                    *
 *----------------------------------------------------------------------------*/
PARSE ARG target

IF target = "" THEN DO
    volume = FILESPEC("DRIVE", VALUE('OS2_SHELL',,'OS2ENVIRONMENT'))
    volume = TRANSLATE( STRIP( volume ))
    volume = STRIP( volume, 'T', ':')
    syslevel = volume":\OS2\INSTALL\SYSLEVEL.OS2"
END
ELSE syslevel = ParseTarget( target )
IF SysLevel = -1 THEN DO
    SAY "Syntax: SYSVER [ file ]"
    RETURN -1
END

slfh.0 = 0
st.0 = 0
r = ReadSysLevel( syslevel )
IF r = 1 THEN DO

    major      = SUBSTR( st.bSysVersion, 1, 1 )
    minor      = SUBSTR( st.bSysVersion, 2, 1 )
    modify     = ABS("0."st.bSysModify )
    refresh    = ABS( st.bRefreshLevel )
    version    = ABS( major"."minor ) + modify
    IF refresh = 0 THEN fullver = version
    ELSE fullver = version"."refresh
    currentCSD = STRIP( st.achCsdLevel, "T", "_")
    priorCSD   = STRIP( st.achCsdPrev, "T", "_")

    PARSE VAR st.achSysName product '00'x junk
    PARSE VAR st.usSysId    subsystem '00'x junk    
    PARSE VAR st.achCompId  component '00'x junk
    PARSE VAR st.achType    type '00'x junk

    SAY
    SAY " " TRANSLATE( FILESPEC("NAME", syslevel ))
    SAY " " product
    SAY
    SAY "  Subsystem ID:" subsystem
    SAY "  Component ID:" component
    SAY "  Type:        " type
    SAY
    SAY "  Version:          " fullver
    SAY "  Current CSD Level:" currentCSD
    SAY "  Prior CSD Level:  " priorCSD

END

RETURN r


/*----------------------------------------------------------------------------*/
ParseTarget: PROCEDURE
    arg target
    IF POS("SYSLEVEL", target ) > 0 THEN
        syslevel = target
    ELSE RETURN -1

RETURN syslevel


/*----------------------------------------------------------------------------*/
ReadSysLevel: procedure expose slfh. st.
call Trace OFF
parse arg fs

   res = 0
   if stream(fs,"C","Query Exists") <> "" then do
      data = charin(fs,1,chars(fs))
      slfh.usSignature   = c2x(reverse(substr(data,1,2)))     /* special # for id of syslevel file */
      slfh.achSignature  = substr(data,3,8)                   /* string to id slf file, must be 'SYSLEVEL' */
      slfh.achJulian     = substr(data,11,5)                  /* date of version */
      slfh.usSlfVersion  = c2x(reverse(substr(data,16,2)))    /* version of syslevel file, must be 1 */
      slfh.ausReserved   = c2x(substr(data,18,16))            /* reserved */
      slfh.ulTableOffset = c2d(reverse(substr(data,34,4)))    /* offset of SYSTABLE */

      /* Calculate table start
      */
      tblst = slfh.ulTableOffset+1

      st.usSysId       = c2x(reverse(substr(data, tblst+0,2))) /* identifies system /subsytem */
      st.bSysEdition   = c2x(substr(data, tblst+2,1))          /* edition of system, eg SE=00, EE=01 */
      st.bSysVersion   = c2x(substr(data, tblst+3,1))          /* version, eg 1.00=10, 1.10=11 */
      st.bSysModify    = c2x(substr(data, tblst+4,1))          /* modify, eg 1.00=00, 1.01=01 */
      st.usSysDate     = c2x(reverse(substr(data, tblst+5,2))) /* date of system */
      st.achCsdLevel   = substr(data, tblst+7,8)               /* subsytem CSD level, eg, XR?0000_ */
      st.achCsdPrev    = substr(data, tblst+15,8)              /* as above, except for prev system */
      st.achSysName    = substr(data, tblst+23,80)             /* Title of system / subsytem (ASCIIZ) */
      st.achCompId     = substr(data, tblst+103,9)             /* component ID of subsytem */
      st.bRefreshLevel = c2x(substr(data, tblst+112,1))
      st.achType       = substr(data, tblst+113,9)             /* Null terminated type (8 chars +'\0') */
      st.usReserved    = substr(data, tblst+122,12)            /* reserved, must be 0 */
      res = 1
      call stream fs,"C","Close"
   end
return res
/*----------------------------------------------------------------------------*/

